@@ -21,6 +21,8 @@
 //#include <QFileInfo>
 #include <QKeySequence>
 
+#include <cmath>
+
 namespace FeatherPad {
 
 Config::Config():
@@ -124,7 +126,7 @@ void Config::readConfig()
     if (settings.value ("splitterPos") == "none")
         remSplitterPos_ = false; // true by default
     else
-        splitterPos_ = qMax (settings.value ("splitterPos", 150).toInt(), 0);
+        splitterPos_ = std::max (settings.value ("splitterPos", 150).toInt(), 0);
 
     prefSize_ = settings.value ("prefSize").toSize();
 
@@ -199,7 +201,7 @@ void Config::readConfig()
     if (settings.value ("font") == "none")
     {
         remFont_ = false; // true by default
-        font_.setPointSize (qMax (QFont().pointSize(), 9));
+        font_.setPointSize (std::max (QFont().pointSize(), 9));
     }
     else
     {
@@ -207,7 +209,7 @@ void Config::readConfig()
         if (!fontStr.isEmpty())
             font_.fromString (fontStr);
         else
-            font_.setPointSize (qMax (QFont().pointSize(), 9));
+            font_.setPointSize (std::max (QFont().pointSize(), 9));
     }
 
     if (settings.value ("noWrap").toBool())
@@ -250,7 +252,7 @@ void Config::readConfig()
         autoSave_ = true; // false by default
 
     int distance = settings.value ("vLineDistance").toInt();
-    if (qAbs (distance) >= 10 && qAbs (distance) < 1000)
+    if (std::abs (distance) >= 10 && std::abs (distance) < 1000)
         vLineDistance_ = distance; // -80 by default
 
     v = settings.value ("skipNonText");
@@ -266,13 +268,13 @@ void Config::readConfig()
     if (settings.value ("pastePaths").toBool())
         pastePaths_ = true; // false by default
 
-    maxSHSize_ = qBound (1, settings.value ("maxSHSize", 2).toInt(), 10);
+    maxSHSize_ = std::clamp (settings.value ("maxSHSize", 2).toInt(), 1, 10);
 
     /* don't let the dark bg be darker than #e6e6e6 */
-    lightBgColorValue_ = qBound (230, settings.value ("lightBgColorValue", 255).toInt(), 255);
+    lightBgColorValue_ = std::clamp (settings.value ("lightBgColorValue", 255).toInt(), 230, 255);
 
     /* don't let the dark bg be lighter than #323232 */
-    darkBgColorValue_ = qBound (0, settings.value ("darkBgColorValue", 15).toInt(), 50);
+    darkBgColorValue_ = std::clamp (settings.value ("darkBgColorValue", 15).toInt(), 0, 50);
 
     dateFormat_ = settings.value ("dateFormat").toString();
 
@@ -287,7 +289,7 @@ void Config::readConfig()
     if (settings.value ("removeTrailingSpaces").toBool())
         removeTrailingSpaces_ = true; // false by default
 
-    recentFilesNumber_ = qBound (0, settings.value ("recentFilesNumber", 10).toInt(), 50);
+    recentFilesNumber_ = std::clamp (settings.value ("recentFilesNumber", 10).toInt(), 0, 50);
     curRecentFilesNumber_ = recentFilesNumber_; // fixed
     recentFiles_ = settings.value ("recentFiles").toStringList();
     recentFiles_.removeAll ("");
@@ -300,9 +302,9 @@ void Config::readConfig()
     if (settings.value ("saveLastFilesList").toBool())
         saveLastFilesList_ = true; // false by default
 
-    autoSaveInterval_ = qBound (1, settings.value ("autoSaveInterval", 1).toInt(), 60);
+    autoSaveInterval_ = std::clamp (settings.value ("autoSaveInterval", 1).toInt(), 1, 60);
 
-    textTabSize_ = qBound (2, settings.value ("textTabSize", 4).toInt(), 10);
+    textTabSize_ = std::clamp (settings.value ("textTabSize", 4).toInt(), 2, 10);
 
     dictPath_ = settings.value ("dictionaryPath").toString();
     spellCheckFromStart_ = settings.value ("spellCheckFromStart").toBool();
@@ -315,7 +317,7 @@ void Config::readConfig()
 void Config::resetFont()
 {
     font_ = QFont ("Monospace");
-    font_.setPointSize (qMax (QFont().pointSize(), 9));
+    font_.setPointSize (std::max (QFont().pointSize(), 9));
 }
 /*************************/
 void Config::readShortcuts()
@@ -367,7 +369,7 @@ void Config::readSyntaxColors()// may be called multiple times
     Settings settingsColors (tmp.fileName(), QSettings::NativeFormat);
 
     settingsColors.beginGroup ("curLineHighlight");
-    curLineHighlight_ = qBound (-1, settingsColors.value ("value", -1).toInt(), 255);
+    curLineHighlight_ = std::clamp (settingsColors.value ("value", -1).toInt(), -1, 255);
     settingsColors.endGroup();
     if (curLineHighlight_ >= 0
         && (darkColScheme_ ? curLineHighlight_ > 70
@@ -636,7 +638,7 @@ void Config::writeSyntaxColors()
 /*************************/
 void Config::setWhiteSpaceValue (int value)
 {
-    value = qBound (getMinWhiteSpaceValue(), value, getMaxWhiteSpaceValue());
+    value = std::clamp (value, getMinWhiteSpaceValue(), getMaxWhiteSpaceValue());
     QList<QColor> colors;
     colors << (darkColScheme_ ? QColor (Qt::white) : QColor (Qt::black));
     if (!customSyntaxColors_.isEmpty())
