@@ -39,7 +39,7 @@ LineEdit::LineEdit (QWidget *parent)
 /*************************/
 void LineEdit::keyPressEvent (QKeyEvent *event)
 {
-    /* because of a bug in Qt5, the non-breaking space (ZWNJ) isn't inserted with SHIFT+SPACE */
+    /* because of a bug in Qt, the non-breaking space (ZWNJ) may not be inserted with SHIFT+SPACE */
     if (event->key() == 0x200c)
     {
         insert (QChar (0x200C));
@@ -59,7 +59,7 @@ void LineEdit::keyPressEvent (QKeyEvent *event)
         if (event->key() == Qt::Key_K)
         {
             clear();
-            returnPressed(); // for clearing found matches highlighting
+            emit returnPressed(); // for clearing found matches highlighting
         }
     }
     QLineEdit::keyPressEvent (event);
