@@ -18,6 +18,7 @@
  */
 
 #include <QGridLayout>
+#include <QAbstractItemView>
 #include <QCompleter>
 #include <QTimer>
 #include "searchbar.h"
@@ -27,6 +28,11 @@ namespace FeatherPad {
 
 static const int MAX_ROW_COUNT = 40;
 
+ComboBox::ComboBox (QWidget *parent) : QComboBox (parent)
+{
+    view()->installEventFilter (this);
+}
+
 void ComboBox::keyPressEvent (QKeyEvent *event)
 {
     if (!(event->modifiers() & Qt::ControlModifier))
@@ -57,25 +63,19 @@ void ComboBox::keyPressEvent (QKeyEvent *event)
     }
     QComboBox::keyPressEvent (event);
 }
-/*************************/
-bool ComboBox::hasPopup() const
+
+bool ComboBox::eventFilter (QObject *watched, QEvent *event)
 {
-    return hasPopup_;
-}
-/*************************/
-void ComboBox::showPopup()
-{
-    hasPopup_ = true;
-    QComboBox::showPopup();
-}
-/*************************/
-void ComboBox::hidePopup()
-{
-    QComboBox::hidePopup();
-    /* wait for the popup to be closed */
-    QTimer::singleShot (0, this, [this]() {
-        hasPopup_ = false;
-    });
+    if (event->type() == QEvent::ShortcutOverride && watched == view() && view()->isVisible())
+    { // prevent "Escape" from doing anything other than closing the popup
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+        if (keyEvent->key() == Qt::Key_Escape && keyEvent->modifiers() == Qt::NoModifier)
+        {
+            event->accept();
+            return false;
+        }
+    }
+    return QComboBox::eventFilter (watched, event);
 }
 /*************************/
 SearchBar::SearchBar(QWidget *parent,
@@ -311,11 +311,6 @@ bool SearchBar::matchRegex() const
     return button_regex_->isChecked();
 }
 /*************************/
-bool SearchBar::hasPopup() const
-{
-    return combo_->hasPopup();
-}
-/*************************/
 // Used only in a workaround (-> FPwin::updateShortcuts())
 void SearchBar::updateShortcuts (bool disable)
 {
