@@ -31,9 +31,11 @@ class FPsingleton : public QApplication
 {
     Q_OBJECT
 public:
-    FPsingleton (int &argc, char **argv, bool standalone);
+    FPsingleton (int &argc, char **argv);
     ~FPsingleton();
 
+    void init (bool standalone);
+
     void sendInfo (const QStringList &info);
     void handleInfo (const QStringList &info);
 
