@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2023 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2025 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -124,7 +124,7 @@ void FPwin::setProgLang (TextEdit *textEdit)
              progLan = "desktop";
         else if (fname.endsWith (".kvconfig")
                  || fname.endsWith (".service") || fname.endsWith (".mount") || fname.endsWith (".timer") // systemd related
-                 || baseName == "sources.list" || baseName == "sources.list.save"
+                 || baseName == "sources.list" || baseName == "sources.list.save" || baseName == "locale.gen"
                  || baseName == "mimeinfo.cache" || baseName == "defaults.list"
                  || baseName == "mimeapps.list" || baseName.endsWith ("-mimeapps.list")
                  || fname.endsWith (".pls", Qt::CaseInsensitive))
@@ -275,7 +275,7 @@ void FPwin::setProgLang (TextEdit *textEdit)
                 progLan = "tcl";
             else if (mime == "application/toml")
                 progLan = "toml";
-            else if (fname.endsWith (".conf") || fname.endsWith (".ini"))
+            else if (fname.endsWith (".conf") || fname.endsWith (".ini") || fname.endsWith (".cfg"))
                 progLan = "config"; // only if the mime type isn't found
             else // fall back to the default language
                 progLan = "url";
