@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2023 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2025 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -92,6 +92,7 @@ public:
                 animation_->setEndValue (g);
                 animation_->start();
                 show();
+                connect (animation_, &QAbstractAnimation::finished, this, &WarningBar::shown);
             });
         }
         else show();
@@ -133,6 +134,7 @@ public:
                 {
                     if (animation_)
                     {
+                        disconnect (animation_, &QAbstractAnimation::finished, this, &WarningBar::shown);
                         animation_->stop();
                         if (isClosing_)
                         {
@@ -157,6 +159,9 @@ public:
         return isClosing_;
     }
 
+signals:
+    void shown(); // used only with printing (-> FPwin::filePrint)
+
 public slots:
     void closeBar() {
         if (animation_ && parentWidget())
@@ -164,6 +169,7 @@ public slots:
             if (!isClosing_)
             {
                 isClosing_ = true;
+                disconnect (animation_, &QAbstractAnimation::finished, this, &WarningBar::shown);
                 animation_->stop();
                 animation_->setStartValue (geometry());
                 animation_->setEndValue (QRect (0, parentWidget()->height() - vOffset_, parentWidget()->width(), 0));
